@@ -25,6 +25,8 @@
 #include "float_cast.h"
 #include <numeric>
 
+#include "DownmixSource.h"
+
 namespace {
 template<typename T, typename F> std::vector<T>
 initVector(size_t dim1, const F &f)
@@ -45,6 +47,8 @@ initVector(size_t dim1, size_t dim2)
 
 namespace
 {
+
+
 void ConsiderStages(const Mixer::Stages& stages, size_t& blockSize)
 {
    for (const auto& stage : stages)
@@ -78,6 +82,11 @@ size_t FindBufferSize(
 
    return blockSize;
 }
+
+auto NeedsDitherPred(const MixerOptions::StageSpecification &spec) {
+   return spec.mpFirstInstance && spec.mpFirstInstance->NeedsDither();
+};
+
 } // namespace
 
 Mixer::Mixer(
@@ -86,26 +95,18 @@ Mixer::Mixer(
    const double stopTime, const unsigned numOutChannels,
    const size_t outBufferSize, const bool outInterleaved, double outRate,
    sampleFormat outFormat, const bool highQuality, MixerSpec* const mixerSpec,
-   ApplyGain applyGain)
+   ApplyVolume applyVolume)
     : mNumChannels { numOutChannels }
     , mInputs { move(inputs) }
     , mMasterEffects { move(masterEffects) }
     , mBufferSize { FindBufferSize(mInputs, mMasterEffects, outBufferSize) }
-    , mApplyGain { applyGain }
+    , mApplyVolume { applyVolume }
     , mHighQuality { highQuality }
     , mFormat { outFormat }
     , mInterleaved { outInterleaved }
     , mTimesAndSpeed { std::make_shared<TimesAndSpeed>(TimesAndSpeed {
          startTime, stopTime, warpOptions.initialSpeed, startTime }) }
 
-    // PRL:  Bug2536: see other comments below for the last, padding argument
-    // TODO: more-than-two-channels
-    // Issue 3565 workaround:  allocate one extra buffer when applying a
-    // GVerb effect stage.  It is simply discarded
-    // See also issue 3854, when the number of out channels expected by the
-    // plug-in is yet larger
-    , mFloatBuffers { 3, mBufferSize, 1, 1 }
-
     // non-interleaved
     , mTemp { mNumChannels, mBufferSize, 1, 1 }
     , mBuffer { initVector<SampleBuffer>(
@@ -125,16 +126,11 @@ Mixer::Mixer(
    // This finds a sufficient, but not necessary, condition to do dithering
    bool needsDither = std::any_of(mInputs.begin(), mInputs.end(),
       [](const Input &input){
-         return std::any_of(input.stages.begin(), input.stages.end(),
-            [](const MixerOptions::StageSpecification &spec){
-               return spec.mpFirstInstance &&
-                  spec.mpFirstInstance->NeedsDither(); } ); } );
+         return std::any_of(input.stages.begin(), input.stages.end(), NeedsDitherPred); }
+   );
    if (mMasterEffects)
       needsDither |= std::any_of(
-         mMasterEffects->begin(), mMasterEffects->end(),
-         [](const MixerOptions::StageSpecification& spec) {
-            return spec.mpFirstInstance && spec.mpFirstInstance->NeedsDither();
-         });
+         mMasterEffects->begin(), mMasterEffects->end(), NeedsDitherPred);
 
    auto pMixerSpec = ( mixerSpec &&
       mixerSpec->GetNumChannels() == mNumChannels &&
@@ -150,45 +146,76 @@ Mixer::Mixer(
       std::accumulate(
          mInputs.begin(), mInputs.end(), 0,
          [](auto sum, const auto& input) {
-            return sum + input.stages.size() * input.pSequence->NChannels();
+            return sum + input.stages.size();
          }) +
       nMasterStages;
    mSettings.reserve(nStages);
    mStageBuffers.reserve(nStages);
 
    size_t i = 0;
+   std::vector<std::unique_ptr<DownmixSource>> downmixSources;
    for (auto &input : mInputs) {
       const auto &sequence = input.pSequence;
       if (!sequence) {
          assert(false);
          break;
       }
-      auto increment = finally([&]{ i += sequence->NChannels(); });
 
       auto &source = mSources.emplace_back(sequence, BufferSize(), outRate,
-         warpOptions, highQuality, mayThrow, mTimesAndSpeed,
-         (pMixerSpec ? &pMixerSpec->mMap[i] : nullptr));
+         warpOptions, highQuality, mayThrow, mTimesAndSpeed);
       AudioGraph::Source *pDownstream = &source;
       for (const auto &stage : input.stages)
          if (
             auto& pNewDownstream =
-               RegisterEffectStage(*pDownstream, stage, outRate))
+               RegisterEffectStage(*pDownstream, sequence->NChannels(), stage, outRate))
          {
             pDownstream = pNewDownstream.get();
          }
-      mDecoratedSources.emplace_back(Source{ source, *pDownstream });
-   }
+      downmixSources.emplace_back(
+         std::make_unique<SequenceDownmixSource>(
+            *pDownstream,
+            *sequence,
+            pMixerSpec ? &pMixerSpec->mMap[i] : nullptr
+         )
+      );
 
-   if (mMasterEffects)
+      i += sequence->NChannels();
+   }
+   
+   if (mMasterEffects && !mMasterEffects->empty())
    {
-      AudioGraph::Source* pDownstream = this;
+      mDownmixStage = std::make_unique<DownmixStage>(
+         std::move(downmixSources), mNumChannels, mBufferSize, ApplyVolume::MapChannels
+      );
+
+      AudioGraph::Source* pDownstream = mDownmixStage.get();
       for (const auto& stage : *mMasterEffects)
+      {
          if (
             auto& pNewDownstream =
-               RegisterEffectStage(*pDownstream, stage, outRate))
+               RegisterEffectStage(*pDownstream, mNumChannels, stage, outRate))
          {
-            mMasterStages.emplace_back(pDownstream = pNewDownstream.get());
+            pDownstream = pNewDownstream.get();
          }
+      }
+
+      //Effect stage could have more than mNumChannels output
+      //and expect at least 3 float buffers input to work correctly...
+      std::vector<std::unique_ptr<DownmixSource>> masterDownmixSources;
+      masterDownmixSources.push_back(std::make_unique<SimpleDonwmixSource>(*pDownstream, mNumChannels));
+      mMasterDownmixStage = std::make_unique<DownmixStage>(
+         std::move(masterDownmixSources), mNumChannels, mBufferSize, ApplyVolume::Mixdown);
+      mDownstream = mMasterDownmixStage.get();
+   }
+   else
+   {
+      mDownmixStage = std::make_unique<DownmixStage>(
+         std::move(downmixSources),
+         mNumChannels,
+         mBufferSize,
+         mApplyVolume
+      );
+      mDownstream = mDownmixStage.get();
    }
 
    // Decide once at construction time
@@ -218,18 +245,18 @@ Mixer::NeedsDither(bool needsDither, double rate) const
       if (sequence.GetRate() != rate)
          // Also leads to MixVariableRates(), needs nontrivial resampling
          needsDither = true;
-      else if (mApplyGain == ApplyGain::Mixdown &&
+      else if (mApplyVolume == ApplyVolume::Mixdown &&
          !mHasMixerSpec &&
          sequence.NChannels() > 1 && mNumChannels == 1)
       {
          needsDither = true;
       }
-      else if (mApplyGain != ApplyGain::Discard) {
+      else if (mApplyVolume != ApplyVolume::Discard) {
          /// TODO: more-than-two-channels
          for (auto c : {0, 1}) {
-            const auto gain = sequence.GetChannelGain(c);
-            if (!(gain == 0.0 || gain == 1.0))
-               // Fractional gain may be applied even in MixSameRate
+            const auto volume = sequence.GetChannelVolume(c);
+            if (!(volume == 0.0 || volume == 1.0))
+               // Fractional volume may be applied even in MixSameRate
                needsDither = true;
          }
       }
@@ -238,7 +265,7 @@ Mixer::NeedsDither(bool needsDither, double rate) const
       // that, remember that some mixers change their time bounds after
       // construction, as when scrubbing.)
       if (!sequence.HasTrivialEnvelope())
-         // Varying or non-unit gain may be applied even in MixSameRate
+         // Varying or non-unit volume may be applied even in MixSameRate
          needsDither = true;
       auto effectiveFormat = sequence.WidestEffectiveFormat();
       if (effectiveFormat > mFormat)
@@ -265,22 +292,6 @@ void Mixer::Clear()
       mTemp.ClearBuffer(c, mBufferSize);
 }
 
-static void MixBuffers(unsigned numChannels,
-   const unsigned char *channelFlags, const float *gains,
-   const float &src, AudioGraph::Buffers &dests, int len)
-{
-   const auto pSrc = &src;
-   for (unsigned int c = 0; c < numChannels; c++) {
-      if (!channelFlags[c])
-         continue;
-      auto dest = &dests.GetWritePosition(c);
-      for (int j = 0; j < len; ++j)
-         dest[j] += pSrc[j] * gains[c];   // the actual mixing process
-   }
-}
-
-#define stackAllocate(T, count) static_cast<T*>(alloca(count * sizeof(T)))
-
 size_t Mixer::Process(const size_t maxToProcess)
 {
    assert(maxToProcess <= BufferSize());
@@ -298,14 +309,10 @@ size_t Mixer::Process(const size_t maxToProcess)
    Clear();
 
    std::optional<size_t> maxOut;
-   if (mMasterStages.empty())
-      maxOut = Acquire(mTemp, maxToProcess);
-   else
-   {
-      const auto stage = mMasterStages.back();
-      maxOut = stage->Acquire(mTemp, maxToProcess);
-      stage->Release();
-   }
+   
+   maxOut = mDownstream->Acquire(mTemp, maxToProcess);
+   mDownstream->Release();
+
    if (!maxOut)
       return 0;
 
@@ -404,117 +411,9 @@ void Mixer::SetSpeedForKeyboardScrubbing(double speed, double startTime)
    mSpeed = fabs(speed);
 }
 
-bool Mixer::AcceptsBuffers(const Buffers& buffers) const
-{
-   return buffers.Channels() == mNumChannels &&
-          AcceptsBlockSize(buffers.BlockSize());
-}
-
-bool Mixer::AcceptsBlockSize(size_t blockSize) const
-{
-   return blockSize <= BufferSize();
-}
-
-sampleCount Mixer::Remaining() const
-{
-   return std::accumulate(
-      mDecoratedSources.begin(), mDecoratedSources.end(), sampleCount { 0 },
-      [](sampleCount sum, const Source& source) {
-         return std::max(sum, source.downstream.Remaining());
-      });
-}
-
-bool Mixer::Release()
-{
-   return true;
-}
-
-std::optional<size_t> Mixer::Acquire(Buffers& data, size_t maxToProcess)
-{
-   // TODO: more-than-two-channels
-   auto maxChannels = std::max(2u, mFloatBuffers.Channels());
-   const auto channelFlags = stackAllocate(unsigned char, mNumChannels);
-   const auto gains = stackAllocate(float, mNumChannels);
-   if (mApplyGain == ApplyGain::Discard)
-      std::fill(gains, gains + mNumChannels, 1.0f);
-
-   // Decides which output buffers an input channel accumulates into
-   auto findChannelFlags = [&channelFlags, numChannels = mNumChannels]
-   (const bool *map, const WideSampleSequence &sequence, size_t iChannel){
-      const auto end = channelFlags + numChannels;
-      std::fill(channelFlags, end, 0);
-      if (map)
-         // ignore left and right when downmixing is customized
-         std::copy(map, map + numChannels, channelFlags);
-      else if (IsMono(sequence))
-         std::fill(channelFlags, end, 1);
-      else if (iChannel == 0)
-         channelFlags[0] = 1;
-      else if (iChannel == 1) {
-         if (numChannels >= 2)
-            channelFlags[1] = 1;
-         else
-            channelFlags[0] = 1;
-      }
-      return channelFlags;
-   };
-
-   size_t maxOut = 0;
-   for (auto c = 0;c < data.Channels(); ++c)
-      data.ClearBuffer(c, maxToProcess);
-
-   for (auto& [upstream, downstream] : mDecoratedSources)
-   {
-      auto oResult = downstream.Acquire(mFloatBuffers, maxToProcess);
-      // One of MixVariableRates or MixSameRate assigns into mTemp[*][*]
-      // which are the sources for the CopySamples calls, and they copy into
-      // mBuffer[*][*]
-      if (!oResult)
-         return 0;
-      const auto result = *oResult;
-      maxOut = std::max(maxOut, result);
-
-      // Insert effect stages here!  Passing them all channels of the track
-
-      const auto limit = std::min<size_t>(upstream.Channels(), maxChannels);
-      for (size_t j = 0; j < limit; ++j)
-      {
-         const auto pFloat = (const float*)mFloatBuffers.GetReadPosition(j);
-         auto& sequence = upstream.GetSequence();
-         if (mApplyGain != ApplyGain::Discard)
-         {
-            for (size_t c = 0; c < mNumChannels; ++c)
-            {
-               if (mNumChannels > 1)
-                  gains[c] = sequence.GetChannelGain(c);
-               else
-                  gains[c] = sequence.GetChannelGain(j);
-            }
-            if (
-               mApplyGain == ApplyGain::Mixdown && !mHasMixerSpec &&
-               mNumChannels == 1)
-               gains[0] /= static_cast<float>(limit);
-         }
-
-         const auto flags =
-            findChannelFlags(upstream.MixerSpec(j), sequence, j);
-         MixBuffers(mNumChannels, flags, gains, *pFloat, data, result);
-      }
-
-      downstream.Release();
-      mFloatBuffers.Advance(result);
-      mFloatBuffers.Rotate();
-   }
-
-   // MB: this doesn't take warping into account, replaced with code based on mSamplePos
-   //mT += (maxOut / mRate);
-
-   assert(maxOut <= maxToProcess);
-   return maxOut;
-}
-
 std::unique_ptr<EffectStage>& Mixer::RegisterEffectStage(
-   AudioGraph::Source& upstream, const MixerOptions::StageSpecification& stage,
+   AudioGraph::Source& upstream, size_t numChannels,
+   const MixerOptions::StageSpecification& stage,
    double outRate)
 {
    // Make a mutable copy of stage.settings
@@ -530,7 +429,7 @@ std::unique_ptr<EffectStage>& Mixer::RegisterEffectStage(
                                      stage.factory();
    };
    auto& pNewDownstream = mStages.emplace_back(EffectStage::Create(
-      -1, mNumChannels, upstream, stageInput, factory, settings, outRate,
+      -1, numChannels, upstream, stageInput, factory, settings, outRate,
       std::nullopt));
    if (!pNewDownstream)
    {
