@@ -163,7 +163,10 @@ public:
    bool IsPluginEnabled(const PluginID & ID);
    void EnablePlugin(const PluginID & ID, bool enable);
 
-   const ComponentInterfaceSymbol & GetSymbol(const PluginID & ID);
+   const ComponentInterfaceSymbol & GetSymbol(const PluginID & ID) const;
+   TranslatableString GetName(const PluginID& ID) const;
+   CommandID GetCommandIdentifier(const PluginID& ID) const;
+   const PluginID& GetByCommandIdentifier(const CommandID& strTarget);
    ComponentInterface *Load(const PluginID & ID);
 
    void ClearEffectPlugins();
@@ -228,8 +231,6 @@ private:
    wxString ConvertID(const PluginID & ID);
 
 private:
-   friend std::default_delete<PluginManager>;
-   static std::unique_ptr<PluginManager> mInstance;
 
    bool IsDirty();
    void SetDirty(bool dirty = true);
