@@ -267,12 +267,14 @@ from there.  Audacity will look for a file called "Pause.png".
    SET_THEME_FLAGS(resFlagNewLine);
    DEFINE_IMAGE(bmpAnonymousUser, wxImage(20, 20), wxT("AnonymousUser"));
    DEFINE_IMAGE(bmpShareAudio, wxImage(20, 20), wxT("ShareAudio"));
+   DEFINE_IMAGE(bmpGoogleLogo, wxImage(20, 20), wxT("GoogleLogo"));
+   DEFINE_IMAGE(bmpFacebookLogo, wxImage(20, 21), wxT("FacebookLogo"));
 
    SET_THEME_FLAGS(resFlagNewLine);
    DEFINE_IMAGE(bmpCogwheel, wxImage(20, 20), wxT("Cogwheel"));
    DEFINE_IMAGE(bmpCloud, wxImage(20, 20), wxT("Cloud"));
    DEFINE_IMAGE(bmpCloudProgress, wxImage(20, 20), wxT("CloudProgress"));
-
+   DEFINE_IMAGE(bmpPlug, wxImage(20, 20), wxT("Plug"));
 
    DEFINE_COLOUR( clrBlank,      wxColour( 64,  64,  64), wxT("Blank"));
    DEFINE_COLOUR( clrUnselected, wxColour( 30,  30,  30), wxT("Unselected"));
@@ -421,5 +423,5 @@ from there.  Audacity will look for a file called "Pause.png".
    DEFINE_COLOUR( clrLoopEnabled,          wxColour( 93,  65,  93),   wxT("LoopEnabled") );
    DEFINE_COLOUR( clrLoopDisabled,         wxColour( 93,  65,  93),   wxT("LoopNotEnabled") );
    DEFINE_COLOUR( clrGrabber,              wxColour( 93,  65,  93),   wxT("Grabber") );
-  
+
    DEFINE_COLOUR( clrTimelineRulerBackground, wxColour( 0xE9, 0xE9, 0xEB ), wxT("TimelineRulerBackground") );
