@@ -13,10 +13,10 @@ Paul Licameli split from Prefs.h
 #define __AUDACITY_FILE_CONFIG__
 
 #include <memory>
-#include "FileConfig.h" // to inherit
+#include <wx/fileconf.h>
 
 /// \brief Our own specialisation of FileConfig.
-class AUDACITY_DLL_API AudacityFileConfig final : public FileConfig
+class AUDACITY_DLL_API AudacityFileConfig final : public wxFileConfig
 {
 public:
    //! Require a call to this factory, to guarantee proper two-phase initialization
@@ -29,10 +29,22 @@ public:
       const wxMBConv& conv = wxConvAuto()
    );
 
+   bool Flush(bool bCurrentOnly) override;
+
    ~AudacityFileConfig() override;
 
+   bool RenameEntry(const wxString& oldName, const wxString& newName) override;
+   bool RenameGroup(const wxString& oldName, const wxString& newName) override;
+   bool DeleteEntry(const wxString& key, bool bDeleteGroupIfEmpty) override;
+   bool DeleteGroup(const wxString& key) override;
+   bool DeleteAll() override;
+
 protected:
-   void Warn() override;
+   bool DoWriteString(const wxString& key, const wxString& szValue) override;
+   bool DoWriteLong(const wxString& key, long lValue) override;
+#if wxUSE_BASE64
+   bool DoWriteBinary(const wxString& key, const wxMemoryBuffer& buf) override;
+#endif
 
 private:
    //! Disallow direct constructor call, because a two-phase initialization is required
@@ -44,5 +56,12 @@ private:
       long style,
       const wxMBConv& conv
    );
+
+   void Init();
+   void Warn() const;
+
+   //wxFileConfig already has m_isDirty flag, but it's inaccessible
+   bool mDirty{false};
+   const wxString mLocalFilename;
 };
 #endif
