@@ -95,7 +95,10 @@ double DefaultPlaybackPolicy::OffsetSequenceTime(
       else {
          // this includes the case where the start time is after the
          // looped region, and mLoopEnabled is set to false
-         time = std::clamp(time + offset, *mpStartTime, schedule.mT1);
+         //
+         // Validate time range
+         if (schedule.mT1 > *mpStartTime)
+            time = std::clamp(time + offset, *mpStartTime, schedule.mT1);
       }
    }
 
