@@ -12,6 +12,7 @@ Paul Licameli split from ProjectWindow.h
 #define __AUDACITY_PROJECT_WINDOW_BASE__
 
 #include <wx/frame.h> // to inherit
+#include <memory>
 
 class AudacityProject;
 
@@ -26,11 +27,13 @@ public:
 
    ~ProjectWindowBase() override;
 
-   AudacityProject &GetProject() { return mProject; }
-   const AudacityProject &GetProject() const { return mProject; }
+   std::shared_ptr<AudacityProject> FindProject()
+      { return mwProject.lock(); }
+   std::shared_ptr<const AudacityProject> FindProject() const
+      { return mwProject.lock(); }
 
 protected:
-   AudacityProject &mProject;
+   std::weak_ptr<AudacityProject> mwProject;
 };
 
 AUDACITY_DLL_API AudacityProject *FindProjectFromWindow( wxWindow *pWindow );
