@@ -16,6 +16,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
+#ifdef __WXGTK3__
+#include <gtk/gtkx.h>
+#endif
+
 #include "RunLoop.h"
 #include "PlugFrame.h"
 
@@ -36,14 +40,21 @@ void SocketWindow::OnMap(GtkWidget* widget, gpointer data)
    if(self->mPlugView->setFrame(frame) == Steinberg::kResultOk)
    {
       self->mPlugView->attached(
-         (void*)gtk_socket_get_id(GTK_SOCKET(widget)), 
+         (void*)gtk_socket_get_id(GTK_SOCKET(widget)),
          Steinberg::kPlatformTypeX11EmbedWindowID
       );
+      ViewRect initialSize;
+      if(self->mPlugView->getSize(&initialSize) == kResultOk)
+         frame->init(self->mPlugView.get(), &initialSize);
    }
 }
 
 SocketWindow::SocketWindow(wxWindow* parent, wxWindowID winid, Steinberg::IPlugView* plugView)
    : wxNativeWindow(parent, winid, gtk_socket_new()), mPlugView(plugView)
 {
+#ifdef __WXGTK3__
+   g_signal_connect(G_OBJECT(GetHandle()), "map", G_CALLBACK(&SocketWindow::OnMap), this);
+#else
    gtk_signal_connect(GTK_OBJECT(GetHandle()), "map", G_CALLBACK(&SocketWindow::OnMap), this);
+#endif
 }
