@@ -10,9 +10,8 @@
 #include "Track.h"
 #include "SelectionState.h"
 #include "../TrackPanel.h"
-#include "../TrackPanelAx.h"
-#include "../commands/CommandContext.h"
-#include "../commands/CommandManager.h"
+#include "TrackFocus.h"
+#include "CommandContext.h"
 #include "../toolbars/ToolManager.h"
 #include "../widgets/AButton.h"
 #include "../widgets/ASlider.h"
@@ -79,17 +78,19 @@ void DoPrevTrack(
    auto &trackFocus = TrackFocus::Get(project);
    auto &tracks = TrackList::Get(project);
    auto &selectionState = SelectionState::Get(project);
+   auto &viewport = Viewport::Get(project);
 
    const auto t = trackFocus.Get();
    if (!t) {
       // if there isn't one, focus on last
       const auto last = *tracks.rbegin();
       trackFocus.Set(last);
-      if (last)
-         last->EnsureVisible(true);
+      if (last) {
+         viewport.ShowTrack(*last);
+         projectHistory.ModifyState(false);
+      }
       return;
    }
-   assert(t->IsLeader());
 
    if (shift) {
       auto p = * -- tracks.Find(t); // Get previous track
@@ -101,41 +102,49 @@ void DoPrevTrack(
          if (circularTrackNavigation)
             p = *tracks.rbegin();
          else {
-            t->EnsureVisible();
+            viewport.ShowTrack(*t);
             return;
          }
       }
       // If here, then there is a nonempty list and a previous track
       // (maybe circularly)
-      assert(p && p->IsLeader());
+      assert(p);
       auto tSelected = t->GetSelected();
       auto pSelected = p->GetSelected();
       if (tSelected && pSelected) {
          selectionState.SelectTrack(*t, false, false);
          trackFocus.Set(p);   // move focus to next track up
-         if (p)
-            p->EnsureVisible(true);
+         if (p) {
+            viewport.ShowTrack(*p);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (tSelected && !pSelected) {
          selectionState.SelectTrack(*p, true, false);
          trackFocus.Set(p);   // move focus to next track up
-         if (p)
-            p->EnsureVisible(true);
+         if (p) {
+            viewport.ShowTrack(*p);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (!tSelected && pSelected) {
          selectionState.SelectTrack(*p, false, false);
          trackFocus.Set(p);   // move focus to next track up
-         if (p)
-            p->EnsureVisible(true);
+         if (p) {
+            viewport.ShowTrack(*p);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (!tSelected && !pSelected) {
          selectionState.SelectTrack(*t, true, false);
          trackFocus.Set(p);   // move focus to next track up
-         if (p)
-            p->EnsureVisible(true);
+         if (p) {
+            viewport.ShowTrack(*p);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
    }
@@ -148,18 +157,21 @@ void DoPrevTrack(
             auto range = tracks.Any();
             p = * range.rbegin(); // null if range is empty
             trackFocus.Set(p);   // Wrap to the last track
-            if (p)
-               p->EnsureVisible(true);
+            if (p) {
+               viewport.ShowTrack(*p);
+               projectHistory.ModifyState(false);
+            }
             return;
          }
          else {
-            t->EnsureVisible();
+            viewport.ShowTrack(*t);
             return;
          }
       }
       else {
          trackFocus.Set(p);   // move focus to next track up
-         p->EnsureVisible(true);
+         viewport.ShowTrack(*p);
+         projectHistory.ModifyState(false);
          return;
       }
    }
@@ -175,17 +187,19 @@ void DoNextTrack(
    auto &trackFocus = TrackFocus::Get(project);
    auto &tracks = TrackList::Get(project);
    auto &selectionState = SelectionState::Get(project);
+   auto &viewport = Viewport::Get(project);
 
    const auto t = trackFocus.Get();
    if  (!t) {
       // if there isn't one, focus on first
       const auto first = *tracks.begin();
       trackFocus.Set(first);
-      if (first)
-         first->EnsureVisible(true);
+      if (first) {
+         viewport.ShowTrack(*first);
+         projectHistory.ModifyState(false);
+      }
       return;
    }
-   assert(t->IsLeader());
 
    if (shift) {
       auto n = * ++ tracks.Find(t); // Get next track
@@ -195,41 +209,49 @@ void DoNextTrack(
          if (circularTrackNavigation)
             n = *tracks.begin();
          else {
-            t->EnsureVisible();
+            viewport.ShowTrack(*t);
             return;
          }
       }
       // If here, then there is a nonempty list and a next track
       // (maybe circularly)
-      assert(n && n->IsLeader());
+      assert(n);
       auto tSelected = t->GetSelected();
       auto nSelected = n->GetSelected();
       if (tSelected && nSelected) {
          selectionState.SelectTrack(*t, false, false);
          trackFocus.Set(n);   // move focus to next track down
-         if (n)
-            n->EnsureVisible(true);
+         if (n) {
+            viewport.ShowTrack(*n);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (tSelected && !nSelected) {
          selectionState.SelectTrack(*n, true, false);
          trackFocus.Set(n);   // move focus to next track down
-         if (n)
-            n->EnsureVisible(true);
+         if (n) {
+            viewport.ShowTrack(*n);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (!tSelected && nSelected) {
          selectionState.SelectTrack(*n, false, false);
          trackFocus.Set(n);   // move focus to next track down
-         if (n)
-            n->EnsureVisible(true);
+         if (n) {
+            viewport.ShowTrack(*n);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
       if (!tSelected && !nSelected) {
          selectionState.SelectTrack(*t, true, false);
          trackFocus.Set(n);   // move focus to next track down
-         if (n)
-            n->EnsureVisible(true);
+         if (n) {
+            viewport.ShowTrack(*n);
+            projectHistory.ModifyState(false);
+         }
          return;
       }
    }
@@ -241,18 +263,21 @@ void DoNextTrack(
          if (circularTrackNavigation) {
             n = *tracks.begin();
             trackFocus.Set(n);   // Wrap to the first track
-            if (n)
-               n->EnsureVisible( true );
+            if (n) {
+               viewport.ShowTrack(*n);
+               projectHistory.ModifyState(false);
+            }
             return;
          }
          else {
-            t->EnsureVisible();
+            viewport.ShowTrack(*t);
             return;
          }
       }
       else {
          trackFocus.Set(n);   // move focus to next track down
-         n->EnsureVisible(true);
+         viewport.ShowTrack(*n);
+         projectHistory.ModifyState(false);
          return;
       }
    }
@@ -426,8 +451,10 @@ void OnCursorDown(const CommandContext &context)
 void OnFirstTrack(const CommandContext &context)
 {
    auto &project = context.project;
+   auto &projectHistory = ProjectHistory::Get(project);
    auto &trackFocus = TrackFocus::Get( project );
    auto &tracks = TrackList::Get( project );
+   auto &viewport = Viewport::Get(project);
 
    auto t = trackFocus.Get();
    if (!t)
@@ -436,26 +463,33 @@ void OnFirstTrack(const CommandContext &context)
    auto f = *tracks.begin();
    if (t != f)
       trackFocus.Set(f);
-   if (f)
-      f->EnsureVisible( t != f );
+   if (f) {
+      viewport.ShowTrack(*f);
+      if (t != f)
+         projectHistory.ModifyState(false);
+   }
 }
 
 void OnLastTrack(const CommandContext &context)
 {
    auto &project = context.project;
+   auto &projectHistory = ProjectHistory::Get(project);
    auto &trackFocus = TrackFocus::Get( project );
    auto &tracks = TrackList::Get( project );
+   auto &viewport = Viewport::Get(project);
 
    Track *t = trackFocus.Get();
-   assert(t->IsLeader());
    if (!t)
       return;
 
    auto l = *tracks.rbegin();
    if (t != l)
       trackFocus.Set(l);
-   if (l)
-      l->EnsureVisible(t != l);
+   if (l) {
+      viewport.ShowTrack(*l);
+      if (t != l)
+         projectHistory.ModifyState(false);
+   }
 }
 
 void OnShiftUp(const CommandContext &context)
@@ -473,17 +507,19 @@ void OnShiftDown(const CommandContext &context)
 void OnToggle(const CommandContext &context)
 {
    auto &project = context.project;
+   auto &projectHistory = ProjectHistory::Get(project);
    auto &trackFocus = TrackFocus::Get(project);
    auto &selectionState = SelectionState::Get(project);
+   auto &viewport = Viewport::Get(project);
 
    Track *t;
 
    t = trackFocus.Get();   // Get currently focused track
    if (!t)
       return;
-   assert(t->IsLeader()); // TrackFocus promises this
    selectionState.SelectTrack(*t, !t->GetSelected(), true);
-   t->EnsureVisible( true );
+   viewport.ShowTrack(*t);
+   projectHistory.ModifyState(false);
 
    trackFocus.UpdateAccessibility();
 
@@ -521,13 +557,11 @@ static CommandHandlerObject &findCommandHandler(AudacityProject &project) {
 #define FN(X) (& NavigationActions::Handler :: X)
 
 namespace {
-using namespace MenuTable;
-BaseItemSharedPtr ExtraGlobalCommands()
+using namespace MenuRegistry;
+auto ExtraGlobalCommands()
 {
    // Ceci n'est pas un menu
-   using Options = CommandManager::Options;
-
-   static BaseItemSharedPtr items{
+   static auto items = std::shared_ptr{
    ( FinderScope{ findCommandHandler },
    Items( wxT("Navigation"),
       Command( wxT("PrevWindow"), XXO("Move Backward Through Active Windows"),
@@ -540,16 +574,15 @@ BaseItemSharedPtr ExtraGlobalCommands()
    return items;
 }
 
-AttachedItem sAttachment2{
-   wxT("Optional/Extra/Part2"),
-   Indirect(ExtraGlobalCommands())
+AttachedItem sAttachment2{ Indirect(ExtraGlobalCommands()),
+   wxT("Optional/Extra/Part2")
 };
 
-BaseItemSharedPtr ExtraFocusMenu()
+auto ExtraFocusMenu()
 {
-   static const auto FocusedTracksFlags = TracksExistFlag() | TrackPanelHasFocus();
-
-   static BaseItemSharedPtr menu{
+   static const auto FocusedTracksFlags =
+      TracksExistFlag() | TrackPanelHasFocus();
+   static auto menu = std::shared_ptr{
    ( FinderScope{ findCommandHandler },
    Menu( wxT("Focus"), XXO("Foc&us"),
       Command( wxT("PrevFrame"),
@@ -578,9 +611,8 @@ BaseItemSharedPtr ExtraFocusMenu()
    return menu;
 }
 
-AttachedItem sAttachment3{
-   wxT("Optional/Extra/Part2"),
-   Indirect(ExtraFocusMenu())
+AttachedItem sAttachment3{ Indirect(ExtraFocusMenu()),
+   wxT("Optional/Extra/Part2")
 };
 
 }
