@@ -4,7 +4,6 @@
 #include "../PluginRegistrationDialog.h"
 #include "../ProjectWindows.h"
 #include "../commands/CommandDispatch.h"
-#include "../effects/EffectManager.h"
 #include "../effects/EffectUI.h"
 #include "../prefs/PrefsDialog.h"
 #include "../toolbars/SelectionBar.h"
@@ -13,6 +12,7 @@
 #include "AudioIO.h"
 #include "CommandContext.h"
 #include "CommandManager.h"
+#include "EffectManager.h"
 #include "HelpSystem.h"
 #include "Journal.h"
 #include "MenuHelper.h"
@@ -30,6 +30,8 @@
 #include "UndoManager.h"
 #include "Viewport.h"
 #include "prefs/EffectsPrefs.h"
+#include "DoEffect.h"
+#include "prefs/GUIPrefs.h"
 
 // private helper classes and functions
 namespace {
@@ -93,7 +95,12 @@ void OnResetConfig(const CommandContext &context)
    SyncLockTracks.Reset();
    SoundActivatedRecord.Reset();
    SelectionToolbarMode.Reset();
+
+   ShowRMSPref().Reset();
+   ShowClippingPref().Reset();
+
    gPrefs->Flush();
+
    DoReloadPreferences(project);
 
    Viewport::Get(project).SetToDefaultSize();
@@ -127,7 +134,7 @@ void OnManageGenerators(const CommandContext &context)
 void OnEffect(const CommandContext &context)
 {
    // using GET to interpret parameter as a PluginID
-   EffectUI::DoEffect(context.parameter.GET(), context, 0);
+   EffectUI::DoEffect(context.parameter.GET(), context.project, 0);
 }
 
 void OnManageEffects(const CommandContext &context)
@@ -149,10 +156,9 @@ void OnRepeatLastGenerator(const CommandContext &context)
    auto& commandManager = CommandManager::Get(context.project);
    auto lastEffect = commandManager.mLastGenerator;
    if (!lastEffect.empty())
-   {
       EffectUI::DoEffect(
-         lastEffect, context, commandManager.mRepeatGeneratorFlags | EffectManager::kRepeatGen);
-   }
+         lastEffect, context.project,
+         commandManager.mRepeatGeneratorFlags | EffectManager::kRepeatGen);
 }
 
 void OnRepeatLastEffect(const CommandContext &context)
@@ -160,10 +166,7 @@ void OnRepeatLastEffect(const CommandContext &context)
    auto& commandManager = CommandManager::Get(context.project);
    auto lastEffect = commandManager.mLastEffect;
    if (!lastEffect.empty())
-   {
-      EffectUI::DoEffect(
-         lastEffect, context, commandManager.mRepeatEffectFlags);
-   }
+      EffectUI::DoEffect(lastEffect, context.project, commandManager.mRepeatEffectFlags);
 }
 
 void OnRepeatLastAnalyzer(const CommandContext& context)
@@ -174,10 +177,8 @@ void OnRepeatLastAnalyzer(const CommandContext& context)
      {
        auto lastEffect = commandManager.mLastAnalyzer;
        if (!lastEffect.empty())
-       {
-         EffectUI::DoEffect(
-            lastEffect, context, commandManager.mRepeatAnalyzerFlags);
-       }
+          EffectUI::DoEffect(
+             lastEffect, context.project, commandManager.mRepeatAnalyzerFlags);
      }
       break;
    case CommandManager::repeattypeunique:
@@ -285,8 +286,9 @@ auto GenerateMenu()
                CommandManager::Get(project).mLastGenerator;
             TranslatableString buildMenuLabel;
             if (!lastGenerator.empty())
-               buildMenuLabel = XO("Repeat %s")
-                  .Format(EffectManager::Get().GetCommandName(lastGenerator));
+               buildMenuLabel =
+                  XO("Repeat %s")
+                     .Format(PluginManager::Get().GetName(lastGenerator));
             else
                buildMenuLabel = XO("Repeat Last Generator");
 
@@ -362,7 +364,7 @@ auto EffectMenu()
          , Command(
             wxT("GetMoreEffects"), XXO("Get more effects..."),
             [](const CommandContext&) {
-               OpenInDefaultBrowser("https://www.musehub.com");
+               OpenInDefaultBrowser("https://www.audacityteam.org/mh-effectmenu");
             },
             AlwaysEnabledFlag)
 #endif
@@ -382,8 +384,9 @@ auto EffectMenu()
             const auto &lastEffect = CommandManager::Get(project).mLastEffect;
             TranslatableString buildMenuLabel;
             if (!lastEffect.empty())
-               buildMenuLabel = XO("Repeat %s")
-                  .Format( EffectManager::Get().GetCommandName(lastEffect) );
+               buildMenuLabel =
+                  XO("Repeat %s")
+                     .Format(PluginManager::Get().GetName(lastEffect));
             else
                buildMenuLabel = XO("Repeat Last Effect");
 
@@ -406,7 +409,8 @@ auto EffectMenu()
                EffectsGroupBy.Read(),
                &OnEffect);
             return result;
-         })) };
+         }))
+   };
    return menu;
 }
 
@@ -442,8 +446,9 @@ auto AnalyzeMenu()
                CommandManager::Get(project).mLastAnalyzer;
             TranslatableString buildMenuLabel;
             if (!lastAnalyzer.empty())
-               buildMenuLabel = XO("Repeat %s")
-                  .Format(EffectManager::Get().GetCommandName(lastAnalyzer));
+               buildMenuLabel =
+                  XO("Repeat %s")
+                     .Format(PluginManager::Get().GetName(lastAnalyzer));
             else
                buildMenuLabel = XO("Repeat Last Analyzer");
 
