@@ -26,21 +26,6 @@ void LabelTrackVRulerControls::Draw(
    const wxRect &rect_, unsigned iPass )
 {
    ChannelVRulerControls::Draw(context, rect_, iPass);
-
-   // Draw on a later pass because the bevel overpaints one pixel
-   // out of bounds on the bottom
-
-   if ( iPass == TrackArtist::PassControls ) {
-      auto rect = rect_;
-      --rect.width;
-      --rect.height;
-
-      auto dc = &context.dc;
-      wxRect bev = rect;
-      bev.Inflate(-1, 0);
-      bev.width += 1;
-      AColor::BevelTrackInfo(*dc, true, bev);
-   }
 }
 
 void LabelTrackVRulerControls::UpdateRuler( const wxRect &rect )
