@@ -16,7 +16,7 @@ Paul Licameli split from TrackPanel.cpp
 
 #include "Envelope.h"
 #include "../../../../HitTestResult.h"
-#include "../../../../prefs/WaveformSettings.h"
+#include "WaveformSettings.h"
 #include "ProjectAudioIO.h"
 #include "ProjectHistory.h"
 #include "../../../../RefreshCode.h"
@@ -30,6 +30,7 @@ Paul Licameli split from TrackPanel.cpp
 #include "WaveTrack.h"
 #include "../../../../../images/Cursors.h"
 #include "AudacityMessageBox.h"
+#include "prefs/WaveformScale.h"
 
 
 static const int SMOOTHING_KERNEL_RADIUS = 3;
