@@ -38,7 +38,7 @@ public:
         bool stretchMode, bool leftBorder);
     ~WaveClipAdjustBorderHandle() override;
 
-   std::shared_ptr<const Channel> FindChannel() const override;
+   std::shared_ptr<const Track> FindTrack() const override;
 
     WaveClipAdjustBorderHandle(WaveClipAdjustBorderHandle&&) noexcept;
     WaveClipAdjustBorderHandle& operator = (WaveClipAdjustBorderHandle&&) noexcept;
