@@ -18,6 +18,10 @@ Paul Licameli split from TrackPanel.cpp
 #include "TimeTrack.h"
 #include "../../../widgets/PopupMenuTable.h"
 #include <wx/numdlg.h>
+#include "ShuttleGui.h"
+#include "wxPanelWrapper.h"
+#include <wx/spinctrl.h>
+#include "AudacityMessageBox.h"
 
 TimeTrackControls::~TimeTrackControls()
 {
@@ -51,46 +55,97 @@ void TimeTrackMenuTable::InitUserData(void *pUserData)
 
 void TimeTrackMenuTable::OnSetTimeTrackRange(wxCommandEvent & /*event*/)
 {
-   TimeTrack *const pTrack = static_cast<TimeTrack*>(mpData->pTrack);
-   if (pTrack) {
-      long lower = (long)(pTrack->GetRangeLower() * 100.0 + 0.5);
-      long upper = (long)(pTrack->GetRangeUpper() * 100.0 + 0.5);
+   auto &track = static_cast<TimeTrack&>(mpData->track);
+   long lower = (long)(track.GetRangeLower() * 100.0 + 0.5);
+   long upper = (long)(track.GetRangeUpper() * 100.0 + 0.5);
 
-      // MB: these lower/upper limits match the maximum allowed range of the time track
-      // envelope, but this is not strictly required
-      lower = wxGetNumberFromUser(_("Change lower speed limit (%) to:"),
-         _("Lower speed limit"),
-         _("Lower speed limit"),
-         lower,
-         TimeTrackControls::kRangeMin,
-         TimeTrackControls::kRangeMax);
+   // MB: these lower/upper limits match the maximum allowed range of the time track
+   // envelope, but this is not strictly required
 
-      upper = wxGetNumberFromUser(_("Change upper speed limit (%) to:"),
-         _("Upper speed limit"),
-         _("Upper speed limit"),
-         upper,
-         lower + 1,
-         TimeTrackControls::kRangeMax);
+   wxDialogWrapper dlg(mpData->pParent, wxID_ANY, XO("Change Speed Limits"));
+   dlg.SetName();
+   ShuttleGui S(&dlg, eIsCreating);
+   wxSpinCtrl *scLower;
+   wxSpinCtrl *scUpper;
 
-      if (lower >= TimeTrackControls::kRangeMin &&
-          upper <= TimeTrackControls::kRangeMax &&
-          lower < upper) {
-         AudacityProject *const project = &mpData->project;
-         pTrack->SetRangeLower((double)lower / 100.0);
-         pTrack->SetRangeUpper((double)upper / 100.0);
-         ProjectHistory::Get( *project )
-            .PushState(XO("Set range to '%ld' - '%ld'").Format( lower, upper ),
-               /* i18n-hint: (verb)*/
-               XO("Set Range"));
-         mpData->result = RefreshCode::RefreshAll;
+   S.StartVerticalLay(true);
+   {
+      S.StartStatic(XO("Change speed limit (%) to:"),1);
+      {
+         S.StartMultiColumn(2, wxEXPAND);
+         {  
+
+            S.SetStretchyCol(1);
+
+            S.AddPrompt(XXO("Lower Speed Limit"));
+            scLower = safenew wxSpinCtrl(S.GetParent(), wxID_ANY,
+               wxT(""),
+               wxDefaultPosition,
+               wxDefaultSize,
+               wxSP_ARROW_KEYS,
+               TimeTrackControls::kRangeMin, TimeTrackControls::kRangeMax, lower);
+            S
+               .Name(XO("Lower Speed Limit"))
+               .Position( wxALIGN_LEFT | wxALL )
+               .AddWindow(scLower);
+
+            S.AddPrompt(XXO("Upper Speed Limit"));
+            scUpper = safenew wxSpinCtrl(S.GetParent(), wxID_ANY,
+               wxT(""),
+               wxDefaultPosition,
+               wxDefaultSize,
+               wxSP_ARROW_KEYS,
+               TimeTrackControls::kRangeMin, TimeTrackControls::kRangeMax, upper);
+            S
+               .Name(XO("Upper Speed Limit"))
+               .Position( wxALIGN_LEFT | wxALL )
+               .AddWindow(scUpper);
+            
+         }
+         S.EndMultiColumn();
       }
+      S.EndStatic();
+      S.AddStandardButtons();
+   }
+   S.EndVerticalLay();
+
+   dlg.Layout();
+   dlg.Fit();
+   dlg.CenterOnParent();
+   if (dlg.ShowModal() == wxID_CANCEL)
+      return;
+
+   while(scLower->GetValue() >= scUpper->GetValue()) {
+      AudacityMessageBox(
+         XO("Upper Speed Limit must be greater than the Lower Speed Limit"),
+         XO("Invalid Limits"),
+         wxOK | wxICON_ERROR,
+         mpData->pParent);
+
+      if (dlg.ShowModal() == wxID_CANCEL)
+         return;
+   }
+
+   lower = scLower->GetValue();
+   upper = scUpper->GetValue();
+
+   if (lower >= TimeTrackControls::kRangeMin &&
+       upper <= TimeTrackControls::kRangeMax) {
+      AudacityProject *const project = &mpData->project;
+      track.SetRangeLower((double)lower / 100.0);
+      track.SetRangeUpper((double)upper / 100.0);
+      ProjectHistory::Get( *project )
+         .PushState(XO("Set range to '%ld' - '%ld'").Format( lower, upper ),
+            /* i18n-hint: (verb)*/
+            XO("Set Range"));
+      mpData->result = RefreshCode::RefreshAll;
    }
 }
 
 void TimeTrackMenuTable::OnTimeTrackLin(wxCommandEvent & /*event*/)
 {
-   TimeTrack *const pTrack = static_cast<TimeTrack*>(mpData->pTrack);
-   pTrack->SetDisplayLog(false);
+   auto &track = static_cast<TimeTrack&>(mpData->track);
+   track.SetDisplayLog(false);
    AudacityProject *const project = &mpData->project;
    ProjectHistory::Get( *project )
       .PushState(XO("Set time track display to linear"), XO("Set Display"));
@@ -101,8 +156,8 @@ void TimeTrackMenuTable::OnTimeTrackLin(wxCommandEvent & /*event*/)
 
 void TimeTrackMenuTable::OnTimeTrackLog(wxCommandEvent & /*event*/)
 {
-   TimeTrack *const pTrack = static_cast<TimeTrack*>(mpData->pTrack);
-   pTrack->SetDisplayLog(true);
+   auto &track = static_cast<TimeTrack&>(mpData->track);
+   track.SetDisplayLog(true);
    AudacityProject *const project = &mpData->project;
    ProjectHistory::Get( *project )
       .PushState(XO("Set time track display to logarithmic"), XO("Set Display"));
@@ -113,15 +168,15 @@ void TimeTrackMenuTable::OnTimeTrackLog(wxCommandEvent & /*event*/)
 
 void TimeTrackMenuTable::OnTimeTrackLogInt(wxCommandEvent & /*event*/)
 {
-   TimeTrack *const pTrack = static_cast<TimeTrack*>(mpData->pTrack);
+   auto &track = static_cast<TimeTrack&>(mpData->track);
    AudacityProject *const project = &mpData->project;
-   if (pTrack->GetInterpolateLog()) {
-      pTrack->SetInterpolateLog(false);
+   if (track.GetInterpolateLog()) {
+      track.SetInterpolateLog(false);
       ProjectHistory::Get( *project )
          .PushState(XO("Set time track interpolation to linear"), XO("Set Interpolation"));
    }
    else {
-      pTrack->SetInterpolateLog(true);
+      track.SetInterpolateLog(true);
       ProjectHistory::Get( *project ).
          PushState(XO("Set time track interpolation to logarithmic"), XO("Set Interpolation"));
    }
@@ -129,21 +184,22 @@ void TimeTrackMenuTable::OnTimeTrackLogInt(wxCommandEvent & /*event*/)
 }
 
 BEGIN_POPUP_MENU(TimeTrackMenuTable)
-   static const auto findTrack = []( PopupMenuHandler &handler ){
-      return static_cast<TimeTrack*>(
-         static_cast<TimeTrackMenuTable&>( handler ).mpData->pTrack );
+   static const auto findTrack =
+   [](PopupMenuHandler &handler) -> TimeTrack & {
+      return static_cast<TimeTrack&>(
+         static_cast<TimeTrackMenuTable&>(handler).mpData->track);
    };
 
    BeginSection( "Scales" );
       AppendRadioItem( "Linear", OnTimeTrackLinID, XXO("&Linear scale"),
          POPUP_MENU_FN( OnTimeTrackLin ),
          []( PopupMenuHandler &handler, wxMenu &menu, int id ){
-            menu.Check( id, !findTrack(handler)->GetDisplayLog() );
+            menu.Check( id, !findTrack(handler).GetDisplayLog() );
          } );
       AppendRadioItem( "Log", OnTimeTrackLogID, XXO("L&ogarithmic scale"),
          POPUP_MENU_FN( OnTimeTrackLog ),
          []( PopupMenuHandler &handler, wxMenu &menu, int id ){
-            menu.Check( id, findTrack(handler)->GetDisplayLog() );
+            menu.Check( id, findTrack(handler).GetDisplayLog() );
          } );
    EndSection();
 
@@ -153,7 +209,7 @@ BEGIN_POPUP_MENU(TimeTrackMenuTable)
       AppendCheckItem( "LogInterp", OnTimeTrackLogIntID,
          XXO("Logarithmic &Interpolation"), POPUP_MENU_FN( OnTimeTrackLogInt),
          []( PopupMenuHandler &handler, wxMenu &menu, int id ){
-            menu.Check( id, findTrack(handler)->GetInterpolateLog() );
+            menu.Check( id, findTrack(handler).GetInterpolateLog() );
          } );
    EndSection();
 
